
.. xoutil documentation master file, created by
   sphinx-quickstart on Fri Jun 15 14:31:00 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to xotl.tools's documentation!
======================================

.. automodule:: xotl.tools

What's new in |release|
-----------------------

.. include:: history/_changes-2.1.0.rst


Contents
--------

.. toctree::
   :maxdepth: 1
   :glob:

   xotl.tools/*
   xoutil
   HISTORY
   CONTRIBUTING
   CONTRIBUTORS
   LICENSE


Indices and tables
==================

* `genindex`:ref:
* `search`:ref:
